
.. _libdoc_misc:

================================================
:mod:`misc.pkl_utils` - Tools for serialization.
================================================

.. testsetup:: *

   from aesara.misc.pkl_utils import *

.. autofunction:: aesara.misc.pkl_utils.dump

.. autofunction:: aesara.misc.pkl_utils.load

.. autoclass:: aesara.misc.pkl_utils.StripPickler

.. seealso::

    :ref:`tutorial_loadsave`
